package service

import (
	"context"
	service "doc-service/domain/repository"
	"doc-service/infra/db"
	"fmt"
	pb "gitlab.galaxy-immi.com/Backend-group/proto/pb/docservice"
	"time"
)

type DocServiceService struct {
	pb.UnimplementedDocServiceServiceServer
}

// 发起文件转换
func (doc *DocServiceService) DoConversion(c context.Context, req *pb.DoConversionRequest) (resp *pb.DoConversionResponse, err error) {

	resp = &pb.DoConversionResponse{}

	request := &service.DoConversionRequest{
		ProjectName: req.ProjectName,
		SourceType:  req.SourceType,
		TargetType:  req.TargetType,
		SourceURI:   req.SourceUrl,
		TargetURI:   req.TargetUrl,
		IsPrivate:   req.IsPrivate,
	}

	request.IsPrivate = true

	//创建项目
	createErr := service.NewConversion().CreateProject()
	fmt.Println(createErr)
	if createErr != nil {
		resp.Msg = createErr.Error()
		resp.Code = 100010
		resp.Data = nil
		return resp, err
	}

	//执行转换
	result, errs := service.NewConversion().Conversion(request)
	if errs != nil {
		resp.Msg = createErr.Error()
		resp.Code = 100010
		resp.Data = nil
		return resp, err
	}
	taskId := result["body"].(map[string]interface{})["TaskId"].(string)

	//入库
	save, errsInfo := db.GetServerSiteMicrosDB().DocServerProject.Create().
		SetProjectName(req.ProjectName).
		SetCreatedAt(time.Now()).
		SetSourceURL(request.SourceURI).
		SetSourceType(req.SourceType).
		SetTargetURL(request.TargetURI).
		SetTaskID(taskId).Save(c)

	if errsInfo != nil {
		resp.Msg = errsInfo.Error()
		resp.Code = 100010
		resp.Data = nil
		return resp, errsInfo
	}

	resp.Msg = "success"
	resp.Code = 200
	resp.Data = &pb.DoConversionData{
		Id:     save.ID,
		TaskId: taskId,
	}
	return resp, nil
}

// 获取转换结果
func (doc *DocServiceService) GetProjectInfo(c context.Context, req *pb.GetProjectRequest) (resp *pb.GetProjectResponse, err error) {
	request := &service.GetTaskRequest{
		ProjectId:         req.ProjectId,
		ProjectName:       req.ProjectName,
		TaskType:          req.TaskType,
		TaskId:            req.TaskId,
		RequestDefinition: req.RequestDefinition,
	}
	request.RequestDefinition = true
	if req.ProjectId > 0 {
		projectData, infoErr := db.GetServerSiteMicrosDB().DocServerProject.Get(c, req.ProjectId)
		if infoErr != nil {
			resp.Msg = err.Error()
			resp.Code = 100010
			resp.Data = nil
			return resp, err
		}
		request.ProjectName = projectData.ProjectName
		request.TaskId = projectData.TaskID
		request.TaskType = projectData.TargetType
	}

	_, errs := service.NewConversion().GetTaskProject(*request)
	if errs != nil {
		resp.Msg = err.Error()
		resp.Code = 100010
		resp.Data = nil
		return resp, err
	}

	resp.Msg = "success"
	resp.Code = 200
	resp.Data = nil
	return resp, nil
}
